package com.bianla.app.activity

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.view.View
import com.bianla.app.R
import com.bianla.app.presenter.ChatUserInfoPresenter
import com.bianla.app.widget.dialog.ReplaceCoachDialog
import com.bianla.app.widget.dialog.ReplaceCoachUpperLimitDialog
import com.bianla.commonlibrary.base.lifecycle.BaseLifeMVPActivity
import com.bianla.commonlibrary.round
import com.bianla.commonlibrary.setLightMode
import com.bianla.commonlibrary.utils.FormatUtils
import com.bumptech.glide.Glide
import com.hyphenate.easeui.widget.EaseAlertDialog
import kotlinx.android.synthetic.main.activity_chat_user_info_layout.*

/**
 *  Project Name : bianla_android
 *  Package Name : com.bianla.app.widget.dialog
 *  @since 2018/3/18 16: 02
 *  @author : TradWang
 *  @email : trad_wang@sina.com
 *  @version :
 *  @describe :
 */
class ChatUserInfoActivity : BaseLifeMVPActivity<ChatUserInfoView, ChatUserInfoPresenter>(), ChatUserInfoView {


    private var mUserType = UserType.TO_USER_TYPE_COMMON
    private var mUserId = -1

    private var mEaseAlertDialog: EaseAlertDialog? = null

    companion object {
        private const val TYPE_KEY = "TYPE_KEY"
        private const val USER_ID_KEY = "USER_ID_KEY"

        /**
         *@param context  activity  or  fragment   context
         * @param userType  user type  eg:  UserType.TO_USER_TYPE_V_COACH
         * @param bianlaId current user `s  bianlaId
         */
        fun startChatUserInfoActivity(context: Context, userType: UserType, bianlaId: Int) {
            val intent = Intent(context, ChatUserInfoActivity::class.java)
            intent.putExtra(TYPE_KEY, userType)
            intent.putExtra(USER_ID_KEY, bianlaId)
            context.startActivity(intent)
        }
    }

    override fun showReplaceCoachUpperLimitTodayDialog() {
        val dialog = ReplaceCoachUpperLimitDialog(this)
        val contentText = dialog.getContentTextView()
        val extraTextView = dialog.getContentExtraTextView()
        val msg = "今日切换教练次数已达上限\n结束咨询后将无法接入\n任何教练"
        contentText.text = msg
        FormatUtils.setTextFormart(contentText, "#40cc45", 8, 13)
        extraTextView.text = "如仍需切换教练，请明日再试"
        dialog.show()
    }

    override fun showReplaceCoachDialog() {
        // 跳转到新会话 发起咨询会话
        val dialog = ReplaceCoachDialog(this@ChatUserInfoActivity, { mPresenter.requestReplaceCoach(mUserId) })
        dialog.show()
    }

    override fun showReplaceCoachUpperLimitAllDialog() {
        val dialog = ReplaceCoachUpperLimitDialog(this)
        val contentText = dialog.getContentTextView()
        val extraTextView = dialog.getContentExtraTextView()
        contentText.text = resources.getString(R.string.replace_coach_upper_limit)
        FormatUtils.setTextFormart(contentText, "#40cc45", 6, 11)
        extraTextView.text = resources.getString(R.string.replace_coach_upper_limit_extra_msg)
        dialog.show()
    }

    override fun fillRemark(remark: String?) {
        tv_remark.text = remark
    }

    override fun fillCoachNum(phone: String) {
        ll_fill_coach_container.isClickable = false
        tv_coach_number.text = phone
    }


    override fun setBasicHelp(isShow: Boolean, totalHelpedNum: Int?, totalHelpedReduceFat: Float?, unit: String?) {
        if (isShow) {
            tv_user_basic_help_container.visibility = View.VISIBLE
            tv_total_help_num.text = totalHelpedNum.round(0)
            tv_total_weight.text = totalHelpedReduceFat.round(1)
            tv_total_weight_unit.text = unit
        } else {
            tv_user_basic_help_container.visibility = View.GONE
        }
    }

    override fun setBasicData(userName: String?, userId: String?, gender: String?, age: Int?, address: String?, avatarUrl: String?, isStudent: Boolean?, isChangeCoach: Boolean) {

        tv_user_name.text = userName

        iv_gender.setImageResource(if ("m" == gender) R.drawable.man else R.drawable.woman)

        val ageStr = "${age}岁"
        tv_age.text = ageStr

        tv_address.text = address

        val idStr = "ID:$userId"
        tv_id.text = idStr

        tv_student.visibility = if (isStudent == true) View.VISIBLE else View.GONE

        tv_student.visibility = if (isChangeCoach == true) View.VISIBLE else View.GONE

        rl_tittle_layout.setBackgroundResource(R.drawable.icon_personal_information_background)

        if (isStudent == true) {
            tv_student.text = "学员"
            tv_student.setBackgroundResource(R.drawable.orange_rectangle_radius_selector)
        } else if (isChangeCoach) {
            tv_student.text = "已换教练"
            tv_student.setBackgroundResource(R.drawable.gray_rectangle_radius_shape)
            rl_tittle_layout.setBackgroundResource(R.drawable.icon_personal_information_background_gray)
            tv_user_name.setTextColor(Color.parseColor("#323232"))
            iv_gender.setImageResource(if ("m" == gender) R.drawable.dark_man else R.drawable.dark_woman)
            tv_age.setTextColor(Color.parseColor("#666666"))
            tv_address.setTextColor(Color.parseColor("#666666"))
            tv_id.setTextColor(Color.parseColor("#666666"))
        }

        Glide.with(this@ChatUserInfoActivity).load(avatarUrl).placeholder(R.drawable.default_female).error(if ("m" == gender) R.drawable.default_male else R.drawable.default_female).into(eiv_avatar)
    }

    override fun setBasicWeight(isShow: Boolean, height: String?, weight: String?, bastWeight: String?, unit: String?) {
        if (isShow) {
            tv_user_basic_weight_container.visibility = View.VISIBLE

            tv_weight.text = weight
            tv_weight_unit.text = unit

            tv_bast_weight.text = bastWeight
            tv_bast_weight_unit.text = unit

            tv_height.text = height
        } else {
            tv_user_basic_weight_container.visibility = View.GONE
        }
    }

    override fun isShowFillCoachView(isShow: Boolean) {
        ll_fill_coach_container.visibility = if (isShow) View.VISIBLE else View.GONE
    }

    override fun isShowFillRemarkView(isShow: Boolean) {
        ll_remark_container.visibility = if (isShow) View.VISIBLE else View.GONE
    }

    override fun isShowFinishConsulting(isShow: Boolean) {
        btn_stop_consulting.visibility = if (isShow) View.VISIBLE else View.GONE
    }

    override fun isShowGoCoachHome(isShow: Boolean) {
        go_coach_home.visibility = if (isShow) View.VISIBLE else View.GONE
    }

    override fun initLayout(): Int {
        return R.layout.activity_chat_user_info_layout
    }

    override fun init() {
        mUserType = intent.getSerializableExtra(TYPE_KEY) as UserType

        mUserId = intent.getIntExtra(USER_ID_KEY, mUserId)
    }

    override fun initPresenter(): ChatUserInfoPresenter {
        return ChatUserInfoPresenter(this)
    }

    override fun attachView(): ChatUserInfoView {
        return this
    }

    override fun initView() {
        setLightMode()
        mEaseAlertDialog = EaseAlertDialog(this@ChatUserInfoActivity, null, "确定删除聊天记录吗？", null, EaseAlertDialog.AlertDialogUser { confirmed, _ ->
            if (confirmed) {
                mPresenter.cleanMessage(mUserId)
            }
        }, true)
    }

    override fun initData() {
        mPresenter.setData(mUserType, mUserId)
    }

    override fun initEvent() {
        btn_back.setOnClickListener { finish() }

        ll_clean_msg_container.setOnClickListener { showCleanMsgDialog() }

        ll_fill_coach_container.setOnClickListener { mPresenter.goToFillCoach(mUserId) }
        ll_remark_container.setOnClickListener { mPresenter.goToFillRemark(mUserId) }
        go_coach_home.setOnClickListener { mPresenter.goCoachHome(mUserId) }
        btn_stop_consulting.setOnClickListener { mPresenter.finishConsulting() }

    }

    private fun showCleanMsgDialog() {
        if (mEaseAlertDialog?.isShowing == true) {
            return
        }
        mEaseAlertDialog?.show()
    }

    override fun go2ActivityForResult(intent: Intent, reCode: Int) {
        startActivityForResult(intent, reCode)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        mPresenter.onActivityResult(resultCode, data)
    }

    enum class UserType {
        /**
         *普通用户打开V认证的用户
         */
        TO_USER_TYPE_V_COACH,
        /**
         *教练打开普通用户
         */
        TO_USER_TYPE_COMMON,
        /**
         *普通用户打开咨询中的教练
         */
        TO_USER_TYPE_CONSULTING_V_COACH
    }

}