package com.bianla.app.activity

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.view.View
import com.bianla.app.R
import com.bianla.app.presenter.ConsultDetailPresenter
import com.bianla.commonlibrary.base.lifecycle.BaseLifeMVPActivity
import com.bianla.commonlibrary.setLightMode
import com.bianla.dataserviceslibrary.domain.OrderTakingListBean
import com.bumptech.glide.Glide
import kotlinx.android.synthetic.main.activity_consult_detail.*

class ConsultDetailActivity : BaseLifeMVPActivity<ConsultDetailView, ConsultDetailPresenter>(), ConsultDetailView {

    private var mOrderTakingListBean: OrderTakingListBean? = null

    override fun setBasicWeight(height: String, weight: String, bastWeight: String, unit: String) {
        tv_weight.text = weight
        tv_weight_unit.text = unit

        tv_bast_weight.text = bastWeight
        tv_bast_weight_unit.text = unit

        tv_height.text = height
    }

    override fun notShowBtn() {
        btn_rob.visibility = View.GONE
    }

    override fun showRobBtn() {
        btn_rob.text = "立即抢单"
        btn_rob.setBackgroundResource(R.drawable.orange_rectangle_radius_selector)
    }

    override fun showConsultBtn() {
        btn_rob.text = "进入会话"
        btn_rob.setBackgroundResource(R.drawable.green_select_btn)
    }

    override fun setRemark(isShow: Boolean, remark: String?) {
        tv_remark.text = remark
        ll_remark_container.visibility = if (isShow) View.VISIBLE else View.GONE
    }


    override fun setBaseInfo(userName: String?, userId: String, gender: String?, age: Int, address: String?, avatarUrl: String, isStudent: Boolean, isChangeCoach: Boolean) {

        tv_user_name.text = userName

        iv_gender.setImageResource(if ("m" == gender) R.drawable.man else R.drawable.woman)

        val ageStr = "${age}岁"
        tv_age.text = ageStr

        tv_address.text = address

        val idStr = "ID:$userId"
        tv_id.text = idStr

        tv_student.visibility = if (isStudent == true) View.VISIBLE else View.GONE

        tv_student.visibility = if (isChangeCoach == true) View.VISIBLE else View.GONE

        rl_tittle_layout.setBackgroundResource(R.drawable.icon_personal_information_background)

        if (isStudent) {
            tv_student.text = "学员"
            tv_student.setBackgroundResource(R.drawable.orange_rectangle_radius_selector)
        } else if (isChangeCoach) {
            tv_student.text = "已换教练"
            tv_student.setBackgroundResource(R.drawable.gray_rectangle_radius_shape)
            rl_tittle_layout.setBackgroundResource(R.drawable.icon_personal_information_background_gray)
            tv_user_name.setTextColor(Color.parseColor("#323232"))
            iv_gender.setImageResource(if ("m" == gender) R.drawable.dark_man else R.drawable.dark_woman)
            tv_age.setTextColor(Color.parseColor("#666666"))
            tv_address.setTextColor(Color.parseColor("#666666"))
            tv_id.setTextColor(Color.parseColor("#666666"))
        }

        Glide.with(this@ConsultDetailActivity).load(avatarUrl).placeholder(R.drawable.default_female).error(if ("m" == gender) R.drawable.default_male else R.drawable.default_female).into(eiv_avatar)
    }

    companion object {

        private const val CONSULT_DATA_KEY = "CONSULT_DATA_KEY"

        fun startActivity(context: Context, orderTakingListBean: OrderTakingListBean) {
            val intent = Intent(context, ConsultDetailActivity::class.java)
            intent.putExtra(CONSULT_DATA_KEY, orderTakingListBean)
            context.startActivity(intent)
        }
    }

    override fun initLayout(): Int {
        return R.layout.activity_consult_detail
    }

    override fun init() {
        mOrderTakingListBean = intent.getParcelableExtra(CONSULT_DATA_KEY) as OrderTakingListBean
    }

    override fun initPresenter(): ConsultDetailPresenter {
        return ConsultDetailPresenter(this)
    }

    override fun attachView(): ConsultDetailView {
        return this
    }

    override fun initView() {
        tv_tittle.text = "个人信息"
        setLightMode()
    }

    override fun initData() {
        mPresenter.setData(mOrderTakingListBean)
    }

    override fun initEvent() {
        btn_back.setOnClickListener { finish() }
        btn_rob.setOnClickListener { mPresenter.onRobClick(mOrderTakingListBean) }
        ll_remark_container.setOnClickListener { mPresenter.goEditRemark(mOrderTakingListBean) }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        mPresenter.onActivityResult(requestCode, resultCode, data)
    }

}
