package com.bianla.app.activity

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.res.AssetFileDescriptor
import android.media.AudioManager
import android.media.SoundPool
import android.os.Bundle
import android.os.CountDownTimer
import android.view.View
import android.view.WindowManager
import android.widget.TextView
import com.bianla.app.R
import com.bianla.app.api.VIE_FOR_ODD_DATA
import com.bianla.app.api.VIE_FOR_ODD_TYPE
import com.bianla.app.api.VIE_FOR_ODD_TYPE_ORDER_UNEXPIRED
import com.bianla.app.presenter.VieForOddPresenter
import com.bianla.commonlibrary.*
import com.bianla.commonlibrary.base.lifecycle.BaseLifeMVPActivity
import com.bianla.commonlibrary.utils.LogUtils
import com.bianla.commonlibrary.utils.TimeUtils
import com.bianla.dataserviceslibrary.domain.OrderTakingListBean
import com.bianla.dataserviceslibrary.manager.BROADCAST_ACTION_REFRESH_CONSULT_LIST
import com.bianla.dataserviceslibrary.manager.BROADCAST_ACTION_ROB_ORDER_FAIL
import com.bianla.dataserviceslibrary.manager.BroadcastManager
import com.bianla.dataserviceslibrary.manager.UPushManager
import com.bumptech.glide.Glide
import io.reactivex.Observable
import io.reactivex.Observer
import io.reactivex.disposables.Disposable
import kotlinx.android.synthetic.main.activity_vie_for_odd.*
import org.json.JSONObject
import java.util.concurrent.TimeUnit

/**
 *  Project Name : bianla_android
 *  Package Name : com.bianla.app.activity
 *  @since 2018/1/5 15: 33
 *  @author : TradWang
 *  @email : trad_wang@sina.com
 *  @version :
 */
class VieForOddActivity : BaseLifeMVPActivity<IVieForOdd, VieForOddPresenter>(), IVieForOdd {

    var mDisposable: Disposable? = null
    private var mVieForOddData: String? = null
    private var mVieForOddType: String? = null

    private var orderId: Int = -1

    private var downTimer: DownTimer? = null

    private var orderTakingListBean: OrderTakingListBean? = null

    private var mSoundPool = SoundPool(2, AudioManager.STREAM_NOTIFICATION, 0)

    private var soundId: Int = 0

    override fun showOrderRobFail() {
        vie_odd_show_ll.visibility = View.GONE
        being_accessed_other_coaches_container.visibility = View.VISIBLE
        i_know_btn.setOnClickListener { finish() }
    }

    private fun resetView() {
        vie_odd_show_ll.visibility = View.VISIBLE
        being_accessed_other_coaches_container.visibility = View.GONE
    }

    override fun initLayout(): Int {
        return R.layout.activity_vie_for_odd
    }

    override fun init() {
        countDownTime()
        initSound()
        downTimer = DownTimer(count_down_tv)

        mVieForOddData = intent.getStringExtra(VIE_FOR_ODD_DATA)
        mVieForOddType = intent.getStringExtra(VIE_FOR_ODD_TYPE)
    }


    override fun initPresenter(): VieForOddPresenter {
        return VieForOddPresenter(this)
    }

    override fun attachView(): IVieForOdd {
        return this
    }

    override fun initView() {
        ov.startAnim()
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        window.addFlags(
                WindowManager.LayoutParams.FLAG_SHOW_WHEN_LOCKED
                        or WindowManager.LayoutParams.FLAG_DISMISS_KEYGUARD
                        or WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON
                        or WindowManager.LayoutParams.FLAG_TURN_SCREEN_ON)
    }

    override fun initData() {
        bindData()
    }

    fun bindData() {

        LogUtils.e("vieForOddData->: $mVieForOddData")

        try {
            val jsonObject = JSONObject(mVieForOddData)

            orderId = jsonObject.getInt("consultId")
            val imId: String? = jsonObject.getString("imId")
            val userId = jsonObject.getString("userId").toIntNotNull()
            val status = jsonObject.getString("status").toIntNotNull()

            val gender: String? = jsonObject.getString("sex")
            val imageUrl: String? = jsonObject.getString("imageUrl")
            imageUrl?.let {
                val into = Glide.with(this@VieForOddActivity).load(it).dontAnimate().placeholder(R.drawable.default_female).error(if ("m" == gender) R.drawable.default_male else R.drawable.default_female).into(civ_user_nickPic)
                into
            }
            user_sex_iv.setImageResource(if ("m" == gender) R.drawable.icon_man else R.drawable.icon_woman)


            val nickName: String? = jsonObject.getString("nickName")
            user_name_tv.text = nickName


            val height = jsonObject.getString("height").toFloatNotNull()
            val heightStr = "身高：${height.round(1)}cm"
            user_height_tv.text = heightStr


            val weight = jsonObject.getString("weight").toFloatNotNull()
            val weightStr = "体重：${(weight * 2).round(1)}斤"
            user_weight_tv.text = weightStr


            val age = jsonObject.getString("age").toIntNotNull()
            val ageStr = "$age 岁"
            user_age_tv.text = ageStr


            val bestWeight = jsonObject.getString("bestWeight").toDoubleNotNull()
            val strWeight = "${(bestWeight * 2).round(1)}斤"
            optimal_weight_tv.text = strWeight


            val region: String? = jsonObject.getString("region")
            user_location_tv.text = region

            val currentTime = jsonObject.getString("currentTime").toLongNotNull()
            val time = "${TimeUtils.getFormatDateToString("yyyy/MM/dd", currentTime * 1000)} ${TimeUtils.get12Hour(currentTime * 1000)}"
            user_advisory_time_tv.text = time

//            val remark: String? = jsonObject.getString("remark")
//            val isVQualified: Int? = jsonObject.getInt("is_vqualified")
//            val isDealer: Int? = jsonObject.getInt("is_dealer")

            val remark: String? = ""
            val isVQualified: Int? = 0
            val isDealer: Int? = 0

            orderTakingListBean = OrderTakingListBean(orderId.toLong(), userId, imId, status, imageUrl, nickName, gender, age, height, weight, bestWeight.toFloat(), region, currentTime, currentTime, 0f, false, false, remark
                    ?: "", isDealer ?: 0, isVQualified ?: 0)


            if (mVieForOddType == VIE_FOR_ODD_TYPE_ORDER_UNEXPIRED) {
                vie_odd_show_ll.visibility = View.VISIBLE
                being_accessed_other_coaches_container.visibility = View.GONE
            } else {
                vie_odd_show_ll.visibility = View.GONE
                being_accessed_other_coaches_container.visibility = View.VISIBLE
            }

            downTimer?.start()

        } catch (e: Exception) {
            LogUtils.e(e.toString())
        }

        mPresenter.postOrderCallBack(orderId)

    }

    public override fun initEvent() {

        vie_odd_container.setDelayClickListener(1, { mPresenter.postReplyConsult(orderTakingListBean) })

        //暂不处理
        no_processing_tv.setOnClickListener {
        mPresenter.giveUpOrder(orderTakingListBean)
        }

        BroadcastManager.registerReceiver(this@VieForOddActivity, BROADCAST_ACTION_ROB_ORDER_FAIL, object : BroadcastReceiver() {
            override fun onReceive(context: Context?, intent: Intent?) {
                showOrderRobFail()
                mSoundPool.stop(soundId)
            }
        })

    }

    override fun onNewIntent(intent: Intent?) {
        super.onNewIntent(intent)
        mVieForOddData = intent?.getStringExtra(VIE_FOR_ODD_DATA)
        mVieForOddType = intent?.getStringExtra(VIE_FOR_ODD_TYPE)
        downTimer?.cancel()
//        downTimer = DownTimer(count_down_tv)
        resetView()
        initSound()
        initData()
    }

    private fun countDownTime() {

        val countDownSubscribe = Observable.interval(0, 1, TimeUnit.SECONDS)
        countDownSubscribe.subscribe(object : Observer<Long> {
            override fun onNext(t: Long) {
                runOnUiThread {
                    advisory_time_tv.text = TimeUtils.getTimeForSeconds(t)
                }

            }

            override fun onError(e: Throwable) {}

            override fun onComplete() {
            }

            override fun onSubscribe(d: Disposable) {
                mDisposable = d
            }

        })

    }

    class DownTimer constructor(val textView: TextView) : CountDownTimer(999 * 1000, 1000) {

        private var count = 1

        override fun onFinish() {
        }

        override fun onTick(millisUntilFinished: Long) {

            count++

            val text = "$count s"
            textView.text = text
        }
    }

    private fun initSound() {

        mSoundPool.stop(soundId)

        try {
            val assetFileDescriptor: AssetFileDescriptor? = assets.openFd("bianlaconsultorder.mp3")
            soundId = if (assetFileDescriptor == null) {
                /*播放声音*/
                mSoundPool.load(this@VieForOddActivity, com.bianla.dataserviceslibrary.R.raw.bianlaconsultorder, 1)
            } else {
                mSoundPool.load(assetFileDescriptor, 1)
            }

            mSoundPool.setOnLoadCompleteListener { soundPool, _, status ->
                if (status == 0) {
                    soundPool.play(soundId, 1f, 1f, 0, 0, 1.1f)
                }
            }
        } catch (t: Throwable) {

        }
    }

    override fun onDestroy() {
        mSoundPool.stop(soundId)
        mSoundPool.release()
        downTimer?.cancel()
        BroadcastManager.unregisterReceiver(this@VieForOddActivity, BROADCAST_ACTION_ROB_ORDER_FAIL)
        downTimer = null
        super.onDestroy()
    }

    override fun onWindowFocusChanged(hasFocus: Boolean) {
        super.onWindowFocusChanged(hasFocus)
        if (hasFocus) {
            UPushManager.cleanRobOrderMsg()
            UPushManager.cleanNotification()
        }
    }
}
