package com.bianla.app.adapter

import android.graphics.Color
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Button
import android.widget.TextView
import com.bianla.app.R
import com.bianla.app.bean.OrderListBean
import com.bianla.commonlibrary.widget.ExtendImageView
import com.bianla.commonlibrary.widget.extrarecyclerview.PushToLoadAdapter
import com.bumptech.glide.Glide

/**
 * ProjectName   bianla_android
 * PackageName  com.bianla.app.adapter
 * @author  TradWang
 * @since   2018/1/6   21:13.
 * @email  wangxiaojun@bianla.cn
 * @version  0.1
 * @describe  订单列表的adapter
 */
class OrderListAdapter constructor(recyclerView: RecyclerView) : PushToLoadAdapter<OrderListBean.DealRegisterListBean, OrderListAdapter.OrderListViewHolder>(recyclerView) {

    private var mRegisterListener: ((OrderListBean.DealRegisterListBean) -> Unit)? = null

    override fun onCreateCommonViewHolder(parent: ViewGroup?, viewType: Int): OrderListAdapter.OrderListViewHolder {
        return OrderListViewHolder(LayoutInflater.from(parent?.context).inflate(R.layout.rv_order_list_item, parent, false))
    }

    override fun onBindCommonViewHolder(holder: OrderListAdapter.OrderListViewHolder?, position: Int) {
        val dealRegisterListBean = mDatas[position]

        holder?.tv_user_name?.text = dealRegisterListBean.nickName

        Glide.with(holder?.itemView?.context).load(if (dealRegisterListBean.imageUrl.isNullOrEmpty()) R.drawable.default_female else dealRegisterListBean.imageUrl).placeholder(R.drawable.default_female).error(R.drawable.default_female).into(holder?.civ_user_nickpic)

        holder?.tv_order_info?.setTextColor(Color.parseColor("#A6A6A6"))
        holder?.tv_order_info?.textSize = 11f

        holder?.consult_btn_confirm?.isEnabled = true

        when (dealRegisterListBean.status) {
            0 -> {
                holder?.tv_order_info?.text = "成交时间：${dealRegisterListBean.dealTime}"
                holder?.consult_btn_confirm?.text = "审核中"
                holder?.consult_btn_confirm?.isEnabled = false
            }
            1 -> {
                val reason = "审核失败：${dealRegisterListBean.refuseReason}"

                holder?.tv_order_info?.setTextColor(Color.parseColor("#FF8A00"))
                holder?.tv_order_info?.textSize = 13f
                holder?.tv_order_info?.text = reason

                holder?.consult_btn_confirm?.text = "重新登记"
                holder?.consult_btn_confirm?.setOnClickListener { mRegisterListener?.invoke(dealRegisterListBean) }
            }
            2 -> {
                holder?.tv_order_info?.text = "成交时间：${dealRegisterListBean.dealTime}"
                holder?.consult_btn_confirm?.text = "已成交"
                holder?.consult_btn_confirm?.isEnabled = false
            }
            9 -> {
                holder?.tv_order_info?.text = "咨询时间：${dealRegisterListBean.dealTime}"
                holder?.consult_btn_confirm?.text = "成交登记"
                holder?.consult_btn_confirm?.setOnClickListener { mRegisterListener?.invoke(dealRegisterListBean) }
            }
        }
    }


    /**
     *未登记
     */
    fun setOnClickRegisterListener(listener: ((OrderListBean.DealRegisterListBean) -> Unit)?) {
        mRegisterListener = listener
    }

    class OrderListViewHolder constructor(view: View) : RecyclerView.ViewHolder(view) {
        val civ_user_nickpic = itemView.findViewById<ExtendImageView>(R.id.civ_user_nickpic)
        val tv_user_name = itemView.findViewById<TextView>(R.id.tv_user_name)
        val tv_order_info = itemView.findViewById<TextView>(R.id.tv_order_info)
        val consult_btn_confirm = itemView.findViewById<Button>(R.id.consult_btn_confirm)
    }

}