package com.bianla.app.enter.register

import com.bianla.app.api.BianlaApi
import com.bianla.app.enter.DownTimeTick
import com.bianla.commonlibrary.App
import com.bianla.commonlibrary.base.lifecycle.BaseActLifePresenter
import com.bianla.dataserviceslibrary.api.ApiFactory
import com.google.gson.JsonObject
import com.trello.rxlifecycle2.LifecycleProvider
import com.trello.rxlifecycle2.android.ActivityEvent
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers

/**
 *  Project Name : bianla_android
 *  Package Name : com.bianla.app.enter.login
 *  @since 2018/3/15 20: 17
 *  @author : TradWang
 *  @email : trad_wang@sina.com
 *  @version :
 *  @describe :
 */
class NewRegisterPresenter constructor(lifecycleProvider: LifecycleProvider<ActivityEvent>) : BaseActLifePresenter<NewRegister>(lifecycleProvider) {

    private var mTickListener: DownTimeTick.TickListener? = null

    private var phone = ""

    private var isPhoneChange = true

    companion object {
        var needNet: Boolean = true
    }

    override fun init() {
        mTickListener = object : DownTimeTick.TickListener {
            override fun onTick(tick: Long) {
                needNet = tick == 0L
            }
        }
    }

    override fun destroy() {
        mView = null
        DownTimeTick.removeListener(mTickListener)
        needNet = true
    }

    /**
     *判断两次输入的电话号码是否是同一个
     * @param newPhone 新的电话号码
     * @return  和之前的比是否相同
     */
    private fun judgePhoneChange(newPhone: String): Boolean {
        return newPhone != phone
    }

    /**
     * 提交电话号码 发送验证码
     * @param phone 提交的电话号码
     */
    fun postPhoneNum(phone: String) {

        isPhoneChange = judgePhoneChange(phone)

        this.phone = phone

        if (needNet || isPhoneChange) {
            mView.showLoading()
            val jsonObject = JsonObject()
            jsonObject.addProperty("phone_number", phone)
            BianlaApi.NetApi.Factory.getApi().sendPhoneNum(ApiFactory.getJsonReqBody(jsonObject.toString())).compose(lifecycleProvider.bindUntilEvent(ActivityEvent.DESTROY))
                    .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe({
                        mView.hideLoading()
                        when (it.code) {
                            1 -> {
                                VerificationCodeInputActivity.startVerificationCodeInputActivity(App.getInstance().currentActivity, phone)
                                DownTimeTick.startDownTick(60)
                                DownTimeTick.addTickListener(mTickListener)
                            }
                            else -> {
                                mView.showToast(it.alertMsg)
                                needNet = true
                            }
                        }
                    }, {
                        needNet = true
                        mView.hideLoading()
                        mView.showToast("发送验证码失败，请稍后再试")
                    })
        } else {
            VerificationCodeInputActivity.startVerificationCodeInputActivity(App.getInstance().currentActivity, phone)
        }
    }
}