package com.bianla.app.model

import com.bianla.app.activity.OrderDetailActivity
import com.bianla.app.api.BianlaApi
import com.bianla.dataserviceslibrary.domain.BaseEntity
import com.bianla.dataserviceslibrary.utils.ImageUtils
import com.google.gson.JsonObject
import io.reactivex.Flowable
import okhttp3.MediaType
import okhttp3.MultipartBody
import okhttp3.RequestBody
import java.io.File

/**
 * ProjectName   bianla_android
 * PackageName  com.bianla.app.model
 * @author  TradWang
 * @since   2018/1/6   19:29.
 * @email  wangxiaojun@bianla.cn
 * @version  0.1
 * @describe  TODO
 */

class OrderDetailModel {
    fun postOrderDealDetail(orderRegisterId: Int, orderUserId: Int, imageList: MutableList<String>, dealMoney: Float, dealCount: Int, orderType: OrderDetailActivity.OrderType, dealOrderNumber: String): Flowable<BaseEntity<JsonObject>> {

        val data = mutableListOf<MultipartBody.Part>()
        //教练的ID
        data.add(MultipartBody.Part.createFormData("consultUserId", orderUserId.toString()))

        //订单的ID
        data.add(MultipartBody.Part.createFormData("dealRegisterId", orderRegisterId.toString()))

        if (orderRegisterId == -1) {
            data.add(MultipartBody.Part.createFormData("operationType", "add"))
        } else {
            data.add(MultipartBody.Part.createFormData("operationType", "modify"))
        }

        when (orderType) {
            OrderDetailActivity.OrderType.ORDER_TYPE_YUN_CHUANG -> {
                //云创
                data.add(MultipartBody.Part.createFormData("dealType", "10"))
            }
            OrderDetailActivity.OrderType.ORDER_TYPE_SHOPPING_MALL -> {
                //商城
                data.add(MultipartBody.Part.createFormData("dealType", "20"))
            }
            OrderDetailActivity.OrderType.ORDER_TYPE_BELLOW_THE_LINE_ORDER -> {
                //线下交易
                data.add(MultipartBody.Part.createFormData("dealType", "30"))
            }
        }
        //订单金额
        data.add(MultipartBody.Part.createFormData("amount", dealMoney.toString()))
        //订单数量
        data.add(MultipartBody.Part.createFormData("quantity", dealCount.toString()))
        //订单号
        data.add(MultipartBody.Part.createFormData("baieOrderNum", dealOrderNumber))
        //是否同意许可
        data.add(MultipartBody.Part.createFormData("agree", "1"))
        //添加图片
        imageList.forEach {
            data.add(MultipartBody.Part.createFormData(
                    "dealImage",
                    "image.jpg",
                    RequestBody.create(MediaType.parse("image/png"), File(ImageUtils.ratioAndGenThumb(it, 750f, false)))))
        }
        return BianlaApi.NetApi.Factory.getApi().postOrderDealDetail(data)
    }
}