package com.bianla.app.presenter

import android.content.Intent
import com.bianla.app.activity.BianLaProtocolActivity
import com.bianla.app.activity.ChatActivity
import com.bianla.app.activity.coach.IConsult
import com.bianla.app.api.BianlaApi
import com.bianla.app.bean.OrderTakingBean
import com.bianla.app.os.BianlaApplication
import com.bianla.commonlibrary.App
import com.bianla.commonlibrary.base.BasePresenter
import com.bianla.commonlibrary.utils.ThreadFactory
import com.bianla.dataserviceslibrary.DataState
import com.bianla.dataserviceslibrary.api.ApiFactory
import com.bianla.dataserviceslibrary.domain.BaseEntity
import com.bianla.dataserviceslibrary.domain.OrderTakingListBean
import com.bianla.dataserviceslibrary.manager.BROADCAST_ACTION_REFRESH_CONSULT_LIST
import com.bianla.dataserviceslibrary.manager.BroadcastManager
import com.bianla.dataserviceslibrary.manager.DaoManager
import com.google.gson.JsonObject
import com.hyphenate.easeui.EaseConstant
import io.reactivex.FlowableSubscriber
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import org.reactivestreams.Subscription

/**
 *  Project Name : bianla_android
 *  Package Name : com.bianla.app.presenter
 *  @since 2018/1/3 21: 24
 *  @author : TradWang
 *  @email : trad_wang@sina.com
 *  @version :
 */
class ConsultPresenter : BasePresenter<IConsult>() {
    override fun init() {

    }

    override fun destroy() {

    }

    fun loadData(page: Int) {
        val jsonObject = JsonObject()
        jsonObject.addProperty("pageNo", page)
        jsonObject.addProperty("pageSize", 20)
        BianlaApi.NetApi.Factory.getApi().getOrderTaking(ApiFactory.getJsonReqBody(jsonObject.toString()))
                .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread()).subscribe(object : FlowableSubscriber<BaseEntity<OrderTakingBean>> {
                    override fun onError(t: Throwable?) {
                        mView.hideRefresh()
                        mView.showToast("数据加载失败点击重试")
                        mView.changeDataState(DataState.DATA_ERROR_STATE)
                    }

                    override fun onNext(t: BaseEntity<OrderTakingBean>?) {
                        mView.hideRefresh()
                        t?.let {
                            if (it.code == 1) {
                                //保存咨询列表数据
                                ThreadFactory.getInstance().singleThreadPool.execute { DaoManager.getInstance().session.orderTakingListBeanDao.insertOrReplaceInTx(it.data.orderTakingList.filter { it.status == 20 }) }
                                if (page == 1) {
                                    if (it.data.orderTakingList.isEmpty()) mView.changeDataState(dataState = DataState.NO_DATA_STATE) else mView.changeDataState(dataState = DataState.HAVE_DATA_STATE)
                                    mView.setData(it.data.orderTakingList)
                                } else {
                                    mView.addData(it.data.orderTakingList)
                                }
                                if (it.data.orderTakingList.size < 20) {
                                    mView.showNoMoreData()
                                }
                            } else {
                                mView.showToast(it.alertMsg)
                                mView.changeDataState(DataState.DATA_ERROR_STATE)
                            }
                        }
                    }

                    override fun onComplete() {

                    }

                    override fun onSubscribe(s: Subscription) {
                        s.request(Long.MAX_VALUE)
                    }

                })
    }

    /**
     *同意咨询（抢单）
     */
    fun replyConsult(data: OrderTakingListBean) {
        val jsonObject = JsonObject()
        jsonObject.addProperty("orderId", data.consultId)
        BianlaApi.NetApi.Factory.getApi().postReplyConsult(ApiFactory.getJsonReqBody(jsonObject.toString())).subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
                .subscribe(object : FlowableSubscriber<BaseEntity<JsonObject>> {
                    override fun onNext(t: BaseEntity<JsonObject>?) {
                        t?.let {
                            if (it.code == 1) {
                                mView.showToast(it.alertMsg)
                                ThreadFactory.getInstance().singleThreadPool.execute {
                                    DaoManager.getInstance().session.orderTakingListBeanDao.insertOrReplaceInTx(data)
                                    App.runOnUiThread { ChatActivity.startChatActivity(BianlaApplication.getInstance().activityContext, EaseConstant.CHATTYPE_SINGLE, data.imId) }

                                }
                            } else {
                                mView.showToast("抢单失败，请稍后重试")
                            }
                        }
                        BroadcastManager.sendBroadcast(App.getAppContext(), Intent(), BROADCAST_ACTION_REFRESH_CONSULT_LIST)
                    }

                    override fun onError(t: Throwable?) {
                        mView.showToast("抢单失败，请稍后重试")
                    }

                    override fun onSubscribe(s: Subscription) {
                        s.request(Long.MAX_VALUE)
                    }

                    override fun onComplete() {
                    }
                })
        burialPointStatistics(data.consultId)
    }

    /**
     *埋点统计抢单次数
     */
    private fun burialPointStatistics(consultId: Long) {
        val jsonObject = JsonObject()
        jsonObject.addProperty("orderId", consultId)
        BianlaApi.NetApi.Factory.getApi().postReadConsultState(ApiFactory.getJsonReqBody(jsonObject.toString())).subscribeOn(Schedulers.io()).subscribe({}, {})
    }
}