package com.bianla.app.presenter

import android.content.Intent
import com.bianla.app.activity.ChatActivity
import com.bianla.app.activity.IVieForOdd
import com.bianla.app.api.BianlaApi
import com.bianla.app.network.ConsultRequest
import com.bianla.app.os.BianlaApplication
import com.bianla.commonlibrary.App
import com.bianla.commonlibrary.base.BasePresenter
import com.bianla.commonlibrary.base.lifecycle.BaseActLifePresenter
import com.bianla.commonlibrary.utils.LogUtils
import com.bianla.commonlibrary.utils.ThreadFactory
import com.bianla.dataserviceslibrary.api.ApiFactory
import com.bianla.dataserviceslibrary.domain.BaseEntity
import com.bianla.dataserviceslibrary.domain.OrderTakingListBean
import com.bianla.dataserviceslibrary.manager.BROADCAST_ACTION_REFRESH_CONSULT_LIST
import com.bianla.dataserviceslibrary.manager.BROADCAST_ACTION_REFRESH_ORDER_LIST
import com.bianla.dataserviceslibrary.manager.BroadcastManager
import com.bianla.dataserviceslibrary.manager.DaoManager
import com.google.gson.JsonObject
import com.hyphenate.easeui.EaseConstant
import com.trello.rxlifecycle2.LifecycleProvider
import com.trello.rxlifecycle2.android.ActivityEvent
import io.reactivex.FlowableSubscriber
import io.reactivex.android.schedulers.AndroidSchedulers
import io.reactivex.schedulers.Schedulers
import org.reactivestreams.Subscription

/**
 *  Project Name : bianla_android
 *  Package Name : com.bianla.app.presenter
 *  @since 2018/1/9 11: 35
 *  @author : TradWang
 *  @email : trad_wang@sina.com
 *  @version :
 *  @describe :
 */
class VieForOddPresenter constructor(lifecycleProvider: LifecycleProvider<ActivityEvent>) : BaseActLifePresenter<IVieForOdd>(lifecycleProvider) {
    override fun init() {
    }

    override fun destroy() {
    }

    fun postReplyConsult(orderTakingListBean: OrderTakingListBean?) {
        if (orderTakingListBean == null) {
            mView.finish()
            return
        }
        mView?.showLoading()
        val jsonObject = JsonObject()
        jsonObject.addProperty("orderId", orderTakingListBean.consultId ?: 0)

        BianlaApi.NetApi.Factory.getApi().postReplyConsult(ApiFactory.getJsonReqBody(json = jsonObject.toString())).subscribeOn(Schedulers.io())
                .compose(lifecycleProvider.bindUntilEvent(ActivityEvent.DESTROY))
                .observeOn(AndroidSchedulers.mainThread()).subscribe(object : FlowableSubscriber<BaseEntity<JsonObject>> {

                    override fun onComplete() {

                    }

                    override fun onNext(t: BaseEntity<JsonObject>?) {
                        mView?.hideLoading()
                        t?.let {
                            if (it.code == 1) {
                                mView.showToast(it.alertMsg)
                                ThreadFactory.getInstance().singleThreadPool.execute {
                                    orderTakingListBean.status = 20
                                    ConsultRequest.getInstance().changeConsultState(ConsultRequest.CONSULT_STATE_CONSULTING)
                                    DaoManager.getInstance().session.orderTakingListBeanDao.insertOrReplaceInTx(orderTakingListBean)
                                    BroadcastManager.sendBroadcast(App.getAppContext(), Intent(), BROADCAST_ACTION_REFRESH_ORDER_LIST)
                                    App.runOnUiThread {
                                        mView?.finish()
                                        ChatActivity.startChatActivity(BianlaApplication.getInstance().activityContext, EaseConstant.CHATTYPE_SINGLE, orderTakingListBean.imId)
                                    }
                                }
                            } else {
                                mView?.showToast("抢单失败")
                                mView?.showOrderRobFail()
                                BroadcastManager.sendBroadcast(App.getAppContext(), Intent(), BROADCAST_ACTION_REFRESH_CONSULT_LIST)
                            }
                        }
                    }

                    override fun onSubscribe(s: Subscription) {
                        s.request(Long.MAX_VALUE)
                    }

                    override fun onError(t: Throwable?) {
                        mView.showToast("抢单失败")
                        mView.hideLoading()
                        mView.showOrderRobFail()
                        BroadcastManager.sendBroadcast(App.getAppContext(), Intent(), BROADCAST_ACTION_REFRESH_CONSULT_LIST)
                    }
                })
    }

    /**
     *订单到达后回调接口
     */
    fun postOrderCallBack(orderId: Int) {

        val jsonObject = JsonObject()
        jsonObject.addProperty("consultId", orderId)

        BianlaApi.NetApi.Factory.getApi().postPostOrderCallBack(ApiFactory.getJsonReqBody(json = jsonObject.toString())).subscribeOn(Schedulers.io())
                .compose(lifecycleProvider.bindUntilEvent(ActivityEvent.DESTROY))
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(object : FlowableSubscriber<BaseEntity<JsonObject>> {
                    override fun onSubscribe(s: Subscription) {
                        s.request(Long.MAX_VALUE)
                    }

                    override fun onNext(t: BaseEntity<JsonObject>?) {
                        LogUtils.i("message : ${t?.alertMsg}   code : ${t?.code}")
                    }

                    override fun onError(t: Throwable?) {
                        LogUtils.e(t?.message)
                    }

                    override fun onComplete() {
                    }

                })
    }

    /**
     * 放弃订单接口
     */
    fun giveUpOrder(orderTakingListBean: OrderTakingListBean?) {
        BroadcastManager.sendBroadcast(App.getAppContext(), Intent(), BROADCAST_ACTION_REFRESH_CONSULT_LIST)
        mView.finish()
        val jsonObject=JsonObject()
        jsonObject.addProperty("",orderTakingListBean?.consultId)
        BianlaApi.NetApi.Factory.getApi().giveUpOrderStatistics(ApiFactory.getJsonReqBody(json = jsonObject.toString())).subscribeOn(Schedulers.io()).subscribe({},{})
    }
}