package com.bianla.app.web

import android.content.Context
import android.content.Intent
import android.graphics.Color
import android.os.Bundle
import android.view.KeyEvent
import android.view.View
import android.view.ViewGroup
import android.webkit.WebView
import com.alibaba.android.arouter.facade.annotation.Route
import com.bianla.app.R
import com.bianla.app.js.JS2Android
import com.bianla.commonlibrary.config.Routes
import com.bianla.commonlibrary.event.EventCenter
import com.bianla.commonlibrary.setLightMode
import com.bianla.commonlibrary.utils.LogUtils
import com.bianla.commonlibrary.web.BaseAgentWebActivity
import kotlinx.android.synthetic.main.activity_web.*
import org.greenrobot.eventbus.Subscribe
import org.greenrobot.eventbus.ThreadMode

@Route(path = Routes.BianlaModule.BIANLA_WEB_VIEW_ACTIVITY)
class WebActivity : BaseAgentWebActivity() {

    private var mUrl = ""

    private var mTitle: String? = ""

    private var mHasTittle = false

    private var mShowCancel = false

    companion object {
        private const val EXTRA_HAS_TITTLE = "extra_has_tittle"
        private const val EXTRA_SHOW_CANCEL = "extra_show_cancel"
        private const val EXTRA_URL = "extra_url"
        private const val TITLE = "extra_title"

        fun startWebViewActivity(context: Context, url: String?, title: String?, showCancel: Boolean) {
            val intent = Intent(context, WebActivity::class.java)
            intent.putExtra(EXTRA_URL, url)
            intent.putExtra(EXTRA_HAS_TITTLE, true)
            intent.putExtra(TITLE, title)
            intent.putExtra(EXTRA_SHOW_CANCEL, showCancel)
            context.startActivity(intent)
        }

        fun startWebViewActivity(context: Context, url: String?) {
            val intent = Intent(context, WebActivity::class.java)
            intent.putExtra(EXTRA_URL, url)
            context.startActivity(intent)
        }
    }

    override fun getAgentWebParent(): ViewGroup {
        return this.findViewById(R.id.ll_container)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        initIntent()
        setContentView(R.layout.activity_web)
        setLightMode()

        agentWeb.agentWebSettings.webSettings.useWideViewPort = true
        agentWeb.jsInterfaceHolder.addJavaObject("Native", JS2Android(this@WebActivity, agentWeb.webCreator.webView, agentWeb.webCreator.webView))

        initData()
        initEvent()
    }

    private fun initIntent() {
        mUrl = intent.getStringExtra(EXTRA_URL)
        mTitle = intent.getStringExtra(TITLE)
        mHasTittle = intent.getBooleanExtra(EXTRA_HAS_TITTLE, false)
        mShowCancel = intent.getBooleanExtra(EXTRA_SHOW_CANCEL, false)

        LogUtils.i("URL -----> :  $mUrl")
    }

    private fun initData() {
        rl_tittle_layout.visibility = if (mHasTittle) View.VISIBLE else View.GONE
        iv_right_btn.visibility = if (mShowCancel) View.VISIBLE else View.GONE
        tv_tittle.text = mTitle

    }

    private fun initEvent() {
        iv_back.setOnClickListener {
            if (!agentWeb.back()) {
                finish()
            }
        }
        iv_right_btn.setOnClickListener { finish() }
    }

    override fun onKeyDown(keyCode: Int, event: KeyEvent): Boolean {
        return if (agentWeb != null && agentWeb.handleKeyEvent(keyCode, event)) {
            true
        } else super.onKeyDown(keyCode, event)
    }

    override fun setTitle(view: WebView, title: String) {
        mTitle?.let {
            tv_tittle.text = it
        }
    }

    override fun getIndicatorColor(): Int {
        return Color.parseColor("#00ff00")
    }

    override fun getIndicatorHeight(): Int {
        return 1
    }

    override fun getUrl(): String? {
        return mUrl
    }

    @Subscribe(threadMode = ThreadMode.MAIN)
    fun onHandleEvent(center: EventCenter) {
        if (center.code == EventCenter.EventCode.CANCEL_BEFORE_WEB_VIEW) {
            finish()
        }
    }
}
